@@ -20,7 +20,14 @@ class PeekFileConfigSqlAlchemyMixin:
             'max_overflow': 50,  # Number that the pool size can exceed when required
             'pool_timeout': 60,  # Timeout for getting conn from pool
             'pool_recycle': 600,  # Reconnect?? after 10 minutes
-            'use_batch_mode': True
+            'executemany_mode': 'batch'  # This supersedes 'use_batch_mode': True,
         }
         with self._cfg as c:
-            return c.sqlalchemy.engineArgs(default, require_dict)
+            val = c.sqlalchemy.engineArgs(default, require_dict)
+            # Upgrade depreciated psycopg setting.
+            if val.get('use_batch_mode') == True:
+                del val['use_batch_mode']
+                val['executemany_mode'] = 'batch'
+                c.sqlalchemy.engineArgs = val
+
+            return val
